import { useEffect, useState } from 'react'
import RenameInput from '../../../../../ui/inputs/RenameInput'
import LabledDropdown from '../../../../../ui/inputs/LabledDropdown'
import Trigger from '../trigger/Trigger'
import { useSelectedEventData, useSelectedProduct } from "../../../../../../store/simulation/useSimulationStore";
import { useProductStore } from "../../../../../../store/simulation/useProductStore";
import StorageAction from '../actions/StorageAction';

function StorageMechanics() {
    const [activeOption, setActiveOption] = useState("default");
    const [selectedPointData, setSelectedPointData] = useState<PointsScheme | undefined>();
    const { selectedEventData } = useSelectedEventData();
    const { getPointByUuid } = useProductStore();
    const { selectedProduct } = useSelectedProduct();

    useEffect(() => {
        if (selectedEventData) {
            const point = getPointByUuid(selectedProduct.productId, selectedEventData?.data.modelUuid, selectedEventData?.selectedPoint);
            if (point && 'action' in point) {
                setSelectedPointData(point as PointsScheme & { action: { actionType: string } });
                setActiveOption((point as PointsScheme & { action: { actionType: string } }).action.actionType);
            }
        }
    }, [selectedProduct, selectedEventData])

    const availableActions = {
        defaultOption: "store",
        options: ["store", "spawn"],
    };
    
    return (
        <>
            {selectedEventData &&
                <>
                    <div className="selected-actions-details">
                        <div className="selected-actions-header">
                            <RenameInput value="Action Name" />
                        </div>
                        <div className="selected-actions-list">
                            <LabledDropdown
                                defaultOption={selectedPointData && 'action' in selectedPointData
                                    ? (selectedPointData as PointsScheme & { action: { actionType: string } }).action.actionType
                                    : "default"}
                                options={availableActions.options}
                                onSelect={(option) => setActiveOption(option)}
                            />
                            {activeOption === "store" && <StorageAction />}
                        </div>
                    </div>
                    <div className="tirgger">
                        <Trigger />
                    </div>
                </>
            }
        </>
    )
}

export default StorageMechanics